@@ -39,7 +39,7 @@ class Weather:
             for day in range(0,6):
                 date = data['list'][day]['dt_txt']
                 only_date = date.split()
-                filename = f"weather_forecast of {city_name} {datetime.datetime.now().strftime('%Y-%m-%d_%I-%M-%S-%p')}.json"
+                filename = f"weather_forecast of {city_name} {datetime.datetime.now().strftime('%Y-%m-%d_%I-%M-%S-%p')}.txt"
                 # create a file with filename variable in append format
                 #print('filename given')
                 with open(filename,'a') as f:
@@ -67,4 +67,4 @@ class Weather:
                     f.write("\n")
                     # closing the file
                     f.close()
-            print("Check output in weather forecast file")
\ No newline at end of file
+            print("Check output in weather forecast file in the same location")
\ No newline at end of file
